# hledger-tools

## make-loan-entries
Make loan entries in the specified journal which include interest expense and liability decrements for each entry.

An example:
```
2026-03-16 Opening Loan: $10,000.00 ; Opening Loan
   assets:cash  $10,000.00
   liabilities:loan  $-10,000.00

2026-03-16 Test Loan for $10,000 over 3 years at 8%
   assets:cash  $-313.37
   expenses:interest  $66.67
   liabilities:loan  $246.70

2026-04-16 Test Loan for $10,000 over 3 years at 8%
   assets:cash  $-313.36
   expenses:interest  $65.02
   liabilities:loan  $248.34

...

2029-01-16 Test Loan for $10,000 over 3 years at 8%
   assets:cash  $-313.37
   expenses:interest  $4.14
   liabilities:loan  $309.23

2029-02-16 Test Loan for $10,000 over 3 years at 8%
   assets:cash  $-313.37
   expenses:interest  $2.08
   liabilities:loan  $311.29

2029-03-16 Test Loan for $10,000 over 3 years at 8%
   assets:cash  $-0.00
   expenses:interest  $0.00
   liabilities:loan  $0.00
```
